@@ -5,15 +5,17 @@ pyrus channel-discover pear.indeyets.ru
 pyrus install -f http://pear.indeyets.ru/get/pake-1.6.3.tgz
 
 # Options
-MIDGARD_LIBS_VERSION=10.05.5.1-1
-MIDGARD_EXT_VERSION=ratatoskr
+MIDGARD_LIBS_VERSION=10.05.7
+MIDGARD_EXT_VERSION=gjallarhorn
 
-# Install Midgard2 library dependencies from OBS
+# Install Midgard2 library dependencies
+sudo add-apt-repository "deb http://security.ubuntu.com/ubuntu precise-security main restricted universe multiverse"
+sudo apt-get --quiet update
 sudo apt-get install -y dbus libglib2.0-dev libgda-4.0-4 libgda-4.0-dev libxml2-dev libdbus-1-dev libdbus-glib-1-dev valgrind php-pear
 
 # Build Midgard2 core from recent tarball
 wget -q https://github.com/midgardproject/midgard-core/tarball/${MIDGARD_EXT_VERSION}
-tar -xzf ratatoskr
+tar -xzf ${MIDGARD_EXT_VERSION}
 sh -c "cd midgardproject-midgard-core-*&&./autogen.sh --prefix=/usr; make; sudo make install"
 rm -f ${MIDGARD_EXT_VERSION}
 
