@@ -185,7 +185,8 @@ STD_PHP_INI_BOOLEAN("midgard.engine",              "1", PHP_INI_ALL,    OnUpdate
 STD_PHP_INI_BOOLEAN("midgard.memory_debug",        "0", PHP_INI_ALL,    OnUpdateBool,   midgard_memory_debug,       zend_midgard2_globals, midgard2_globals)
 STD_PHP_INI_BOOLEAN("midgard.superglobals_compat", "0", PHP_INI_SYSTEM, OnUpdateBool,   superglobals_compat,        zend_midgard2_globals, midgard2_globals)
 STD_PHP_INI_BOOLEAN("midgard.valgrind_friendly",   "0", PHP_INI_SYSTEM, OnUpdateBool,   valgrind_friendly,          zend_midgard2_globals, midgard2_globals)
-STD_PHP_INI_BOOLEAN("midgard.glib_loghandler",	"0", PHP_INI_SYSTEM, OnUpdateBool,   glib_loghandler,          zend_midgard2_globals, midgard2_globals)
+STD_PHP_INI_BOOLEAN("midgard.glib_loghandler",	   "0", PHP_INI_SYSTEM, OnUpdateBool,   glib_loghandler,            zend_midgard2_globals, midgard2_globals)
+STD_PHP_INI_BOOLEAN("midgard.schema_path",	   "",  PHP_INI_SYSTEM, OnUpdateString, schema_path,	            zend_midgard2_globals, midgard2_globals)
 PHP_INI_END()
 
 static zend_bool php_midgard_engine_is_enabled(TSRMLS_D)
@@ -235,6 +236,32 @@ static zend_bool php_midgard_initialize_configs(TSRMLS_D)
 	return TRUE;
 }
 
+static void php_midgard_initialize_schema_from_path(TSRMLS_D)
+{
+	const char *user_defined_path = MGDG(schema_path);
+	if (user_defined_path == NULL
+			|| (user_defined_path && *user_defined_path =='\0'))
+		return;
+
+	char **paths = g_strsplit_set(user_defined_path, ";:", 0);
+	if (paths == NULL)
+		return;
+
+	int i;
+	MidgardSchema *schema = g_object_new(MIDGARD_TYPE_SCHEMA, NULL);
+	for(i = 0; paths[i] != NULL; i++) {
+		if (*paths[i] == '\0')
+			continue;
+		zend_bool success = midgard_schema_read_dir(schema, paths[i]);
+		if (success == FALSE) {
+			php_error(E_WARNING, "Failed to read schema from given '%s' directory.", paths[i]);
+		}
+	}
+
+	g_object_unref (schema);
+	g_strfreev(paths);
+}
+
 static void php_midgard_initialize_schema(TSRMLS_D)
 {
 	if (midgard_global_schema != NULL) {
@@ -323,11 +350,25 @@ PHP_MINIT_FUNCTION(midgard2)
 
 	midgard_init();
 
+	/* Implicitly initialize Midgard types.
+	 * With GObject Introspection it's done out of the box */
+	GType _init_type;
+	_init_type = MIDGARD_TYPE_SQL_CONTENT_MANAGER_JOB_LOAD;
+	_init_type = MIDGARD_TYPE_SQL_CONTENT_MANAGER_JOB_CREATE;
+	_init_type = MIDGARD_TYPE_SQL_CONTENT_MANAGER_JOB_UPDATE;
+	_init_type = MIDGARD_TYPE_SQL_CONTENT_MANAGER_JOB_DELETE;
+	_init_type = MIDGARD_TYPE_SQL_CONTENT_MANAGER_JOB_PURGE;
+	_init_type = MIDGARD_TYPE_SQL_CONTENT_MANAGER;
+	_init_type = MIDGARD_TYPE_EXECUTION_POOL;
+
 	REGISTER_INI_ENTRIES();
 
 	/* register Gtype types from schemas */
 	php_midgard_initialize_schema(TSRMLS_C);
 
+	/* register GType types from user defined paths */
+	php_midgard_initialize_schema_from_path(TSRMLS_C);
+
 	/* Initialize handlers */
 	memcpy(&php_midgard_gobject_handlers, zend_get_std_object_handlers(),
 		   sizeof(zend_object_handlers));
@@ -379,6 +420,10 @@ PHP_MINIT_FUNCTION(midgard2)
 	PHP_MINIT(midgard2_reflector_property)(INIT_FUNC_ARGS_PASSTHRU);
 	PHP_MINIT(midgard2_repligard)(INIT_FUNC_ARGS_PASSTHRU);
 	PHP_MINIT(midgard2_query_selectors)(INIT_FUNC_ARGS_PASSTHRU);
+	PHP_MINIT(midgard2_model)(INIT_FUNC_ARGS_PASSTHRU);
+	PHP_MINIT(midgard2_job)(INIT_FUNC_ARGS_PASSTHRU);
+	PHP_MINIT(midgard2_content_manager)(INIT_FUNC_ARGS_PASSTHRU);
+	PHP_MINIT(midgard2_pool)(INIT_FUNC_ARGS_PASSTHRU);
 
 	/* Register midgard_metadata class */
 	static zend_class_entry midgard_metadata_class_entry;
@@ -534,7 +579,7 @@ PHP_MSHUTDOWN_FUNCTION(midgard2)
 PHP_RINIT_FUNCTION(midgard2)
 {
 	if (!php_midgard_engine_is_enabled(TSRMLS_C))
-		return FAILURE;
+		return SUCCESS;
 
 	if (MGDG(midgard_memory_debug)) {
 		php_printf("RINIT\n");
@@ -544,7 +589,7 @@ PHP_RINIT_FUNCTION(midgard2)
 		/* all_configs is set during MINIT */
 		if (MGDG(all_configs) == NULL) {
 			php_error(E_ERROR, "[Midgard2 rinit] Can not handle request without midgard connection");
-			return FAILURE;
+			return SUCCESS;
 		}
 
 		// preinitialization of connection (in the future it won't be needed)
@@ -583,6 +628,9 @@ PHP_RINIT_FUNCTION(midgard2)
 
 PHP_RSHUTDOWN_FUNCTION(midgard2)
 {
+	if (!php_midgard_engine_is_enabled(TSRMLS_C))
+		return SUCCESS;
+
 	MGDG(can_deliver_signals) = 0;
 
 	if (MGDG(midgard_memory_debug)) {
